<div class="border-b border-t border-base-200 font-semibold -mx-3 py-2.5 px-3 text-font-important-light first:border-t-0 first:-mt-5 dark:border-base-800 dark:text-font-important-dark">
    {{ title }}
</div>
