<div class="flex flex-row gap-2 max-w-2xl">
    <div class="w-2/3">
        {% with widget=widget.subwidgets.0 %}
            {% include widget.template_name %}
        {% endwith %}
    </div>

    <div class="w-1/3">
        {% with widget=widget.subwidgets.1 %}
            {% include widget.template_name %}
        {% endwith %}
    </div>
</div>
