<{% if href %}a href="{{ href }}"{% else %}button{% endif%} {% if submit %}type="submit"{% endif%} {% if name %}name="{{ name }}"{% endif %}
class="font-medium flex group items-center gap-2 px-3 py-2 rounded-default justify-center whitespace-nowrap {% if attrs.disabled %}cursor-not-allowed opacity-50{% else %}cursor-pointer{% endif %}
{% if variant == "default" %}
    border border-base-200 bg-white text-font-important-light dark:border-base-700 dark:bg-transparent dark:text-font-important-dark
{% elif variant == "secondary" %}
    bg-gray-100 border border-transparent dark:bg-base-800
{% elif variant == "ghost" %}
    bg-transparent text-font-important-light dark:text-font-important-dark
{% else %}
    border border-base-200 bg-primary-600 border-transparent text-white
{% endif %}{% if class %} {{ class }}{% endif %}" {% include "unfold/helpers/attrs.html" %}>
{{ children }}
</{% if href %}a{% else %}button{% endif%}>
